@@ -70,9 +70,11 @@ async def get_gemini_payload(request, engine, provider, api_key=None):
                 elif item.type == "image_url" and provider.get("image", True):
                     image_message = await get_image_message(item.image_url.url, engine)
                     content.append(image_message)
-        else:
+        elif msg.content:
             content = [{"text": msg.content}]
             tool_calls = msg.tool_calls
+        elif msg.content is None:
+            continue
 
         if tool_calls:
             tool_call = tool_calls[0]
@@ -182,9 +184,15 @@ async def get_gemini_payload(request, engine, provider, api_key=None):
                 processed_tools = []
                 for tool in value:
                     function_def = tool["function"]
+                    # gemini不支持parameters里面的additionalProperties字段，需要删除
+                    if safe_get(function_def, "parameters", "additionalProperties", default=None) is not None:
+                        del function_def["parameters"]["additionalProperties"]
+
                     # 处理 parameters.properties 中的 default 字段
                     if safe_get(function_def, "parameters", "properties", default=None):
                         for prop_value in function_def["parameters"]["properties"].values():
+                            if "additionalProperties" in prop_value:
+                                del prop_value["additionalProperties"]
                             if "default" in prop_value:
                                 # 将 default 值添加到 description 中
                                 default_value = prop_value["default"]
